#
# spec file for package python-sorl-thumbnail
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
Name:           python-sorl-thumbnail
Version:        12.7.0
Release:        2.1
Summary:        Thumbnails for Django
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/jazzband/sorl-thumbnail
Source:         https://files.pythonhosted.org/packages/source/s/sorl-thumbnail/sorl-thumbnail-%{version}.tar.gz
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  lsof
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 2
Recommends:     ImageMagick
Recommends:     python-dbm
Suggests:       GraphicsMagick
Suggests:       python-Wand
Suggests:       python-pgmagick
Suggests:       vips-tools
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Django >= 2}
BuildRequires:  %{python_module boto}
BuildRequires:  %{python_module dbm}
BuildRequires:  %{python_module pytest-django}
BuildRequires:  %{python_module redis}
BuildRequires:  %{pythons}
BuildRequires:  GraphicsMagick
BuildRequires:  ImageMagick
BuildRequires:  python3-pgmagick
BuildRequires:  redis
BuildRequires:  vips-tools
# /SECTION
%python_subpackages

%description
Thumbnails for Django.

Features at a glance
---------------------
- Storage support
- Pluggable Engine support (PIL, pgmagick)
- Pluggable Key Value Store support (redis, cached db)
- Pluggable Backend support
- Admin integration with possibility to delete
- Dummy generation
- Flexible, simple syntax, generates no html
- ImageField for model that deletes thumbnails
- CSS style cropping options
- Margin calculation for vertical positioning

%prep
%setup -q -n sorl-thumbnail-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8

PYTHONPATH=.
export DJANGO_SETTINGS_MODULE=tests.settings.pil
%pytest -rs -k 'not TemplateTestCaseB and not test_image_file_deserialize'
export DJANGO_SETTINGS_MODULE=tests.settings.imagemagick
%pytest -rs -k 'not TemplateTestCaseB and not test_image_file_deserialize'
export DJANGO_SETTINGS_MODULE=tests.settings.dbm
%pytest -rs -k 'not TemplateTestCaseB and not test_image_file_deserialize'
export DJANGO_SETTINGS_MODULE=tests.settings.graphicsmagick
%pytest -rs -k 'not TemplateTestCaseB and not test_image_file_deserialize'

# pgmagick is not installed in all environments
%{python_expand if [ -d %{$python_sitearch}/pgmagick/ ]; then
  export DJANGO_SETTINGS_MODULE=tests.settings.pgmagick
  $python -m pytest -rs -k 'not (TemplateTestCaseB or test_image_file_deserialize or test_is_valid_image)'
fi
}

%{_sbindir}/redis-server &
export DJANGO_SETTINGS_MODULE=tests.settings.redis
# skipping test_write and test_no_source_get_image skipped as they count open file descriptors and sometimes is off
%pytest -rs -k 'not (TemplateTestCaseB or test_image_file_deserialize or test_no_source_get_image or test_write)'

%files %{python_files}
%doc AUTHORS CHANGES.rst README.rst
%license LICENSE
%{python_sitelib}/*

%changelog
* Mon Feb 22 2021 John Vandenberg <jayvdb@gmail.com>
- Disable pgmagick tests on Tumbleweed Python 3.6 due to broken
  python36-pgmagick
* Tue Nov 24 2020 John Vandenberg <jayvdb@gmail.com>
- Require Python 3 & Django 2+, fixing builds on Leap 15.x
- Skip flaky test test_no_source_get_image which counts open file
  descriptors
- Update to v12.7.0
  * Drop support for Django 1.11
  * Added support for Django 3.1
  * Correction in convert_engine with unknown exif orientation
  * Using more resilient _get_exif_orientation logic in convert engine
  * Update wand_engine.py for ImageMagick 7
  * Fix cannot write mode RGBA as JPEG when thumbnailing a GIF
* Wed Sep  2 2020 Marketa Calabkova <mcalabkova@suse.com>
- Fix test execution
* Sun May 31 2020 John Vandenberg <jayvdb@gmail.com>
- Activated test suites
* Wed Apr  1 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v12.6.3
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Tue Jan  3 2012 alexandre@exatati.com.br
- Update to 11.12:
  - Sorry, no changelog atm.
- Remove CFLAGS and %%clean section from spec file;
- License in SPDX format.
* Wed Sep 14 2011 alexandre@exatati.com.br
- Update to 11.09:
  - Sorry, no changelog.
* Fri Apr 29 2011 alexandre@exatati.com.br
- Update to 11.05.1:
  - Sorry, no changelog.
* Thu Apr 28 2011 alexandre@exatati.com.br
- Update to 11.05:
  - Sorry, no changelog.
* Wed Apr 20 2011 alexandre@exatati.com.br
- Update to 11.04:
- Regenerate spec file with py2pack.
* Sat Jan 29 2011 alexandre@exatati.com.br
- Update to 11.01;
- Spec file cleaned with spec-cleaner;
- Bzip2 source file.
* Sun Jun 20 2010 nix@opensuse.org
- Make wv a Recommends and change from wv2 to libwv2
* Mon Oct  5 2009 alexandre@exatati.com.br
- Update to 3.2.5;
- Building as noarch for openSUSE >= 11.2.
* Fri Sep 18 2009 alexandre@exatati.com.br
- Update to 3.2.4.
* Tue Sep 15 2009 alexandre@exatati.com.br
- Update to 3.2.3.
* Fri Aug 28 2009 alexandre@exatati.com.br
- Update to 3.2.2.
* Tue Aug 18 2009 alexandre@exatati.com.br
- Initial package (3.2) for openSUSE.
